remove 'get' prefix in methods
diff --git a/openstack/storage/v1/accounts/urls.go b/openstack/storage/v1/accounts/urls.go
index ae78ff2..53b1343 100644
--- a/openstack/storage/v1/accounts/urls.go
+++ b/openstack/storage/v1/accounts/urls.go
@@ -2,7 +2,7 @@
 
 import "github.com/rackspace/gophercloud"
 
-// getAccountURL returns the URI for making Account requests.
-func getAccountURL(c *gophercloud.ServiceClient) string {
+// accountURL returns the URI for making Account requests.
+func accountURL(c *gophercloud.ServiceClient) string {
 	return c.Endpoint
 }